# RAATK
A python-based reduce amino acid toolkit of machine learning for protein-dependent inference.

Installation
------------
create a new virtual environment:
```{.sourceCode .bash}
$conda create -n test python=3.6
$source activate test
```
install
``` {.sourceCode .bash}
$ pip install git+https://github.com/huang-sh/raatk.git@dev -U
```
 Function
 ------------
- [view reduced amio acid alphabet](https://github.com/huang-sh/raatk/wiki#view)
- [reduce amino acid sequence](https://github.com/huang-sh/raatk/wiki#reduce)
- [extract sequence feature](https://github.com/huang-sh/raatk/wiki#extract)    
- [evaluation](https://github.com/huang-sh/raatk/wiki#eval)    
- [visualization](https://github.com/huang-sh/raatk/wiki#plot)    
- [train model](https://github.com/huang-sh/raatk/wiki#train)    
- [prediction](https://github.com/huang-sh/raatk/wiki#predict)    
- [feature selection](https://github.com/huang-sh/raatk/wiki#ifs)   
- [hyper-parameter optimization](https://github.com/huang-sh/raatk/wiki#-hpo)    
- [split data](https://github.com/huang-sh/raatk/wiki#split)

